summaryrefslogtreecommitdiffstats
path: root/ci/cyclicTestTrigger.sh
diff options
context:
space:
mode:
Diffstat (limited to 'ci/cyclicTestTrigger.sh')
-rwxr-xr-xci/cyclicTestTrigger.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/ci/cyclicTestTrigger.sh b/ci/cyclicTestTrigger.sh
index d8370fd71..6241452a2 100755
--- a/ci/cyclicTestTrigger.sh
+++ b/ci/cyclicTestTrigger.sh
@@ -29,12 +29,12 @@ function verifyGuestImage {
fi
}
#Updating the pod.yaml file with HOST_IP,cyclictest-node-context.yaml with loops and interval
function updateYaml {
cd $WORKSPACE/tests/
sed -ri "s/[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}/${HOST_IP}/" pod.yaml
- sed -ri "s/loops: [0-9]*/loops: ${testTime}/" cyclictest-node-context.yaml
- sed -ri "0,/interval: [0-9]*/s//interval: 1000/" cyclictest-node-context.yaml
+ sed -ri "s/loops: [0-9]*/loops: ${testTime}/" kvmfornfv_cyclictest_idle_idle.yaml
+ sed -ri "0,/interval: [0-9]*/s//interval: 1000/" kvmfornfv_cyclictest_idle_idle.yaml
}
#cleaning the environment after executing the test through yardstick.
@@ -83,7 +83,7 @@ function runCyclicTest {
#copying required files to run yardstick cyclic testcase
mv $WORKSPACE/build_output/kernel-${KERNELRPM_VERSION}*.rpm ${volume}/rpm
cp -r $WORKSPACE/ci/envs/* ${volume}/scripts
- cp -r $WORKSPACE/tests/cyclictest-node-context.yaml ${volume}
+ cp -r $WORKSPACE/tests/kvmfornfv_cyclictest_idle_idle.yaml ${volume}
cp -r $WORKSPACE/tests/pod.yaml ${volume}/scripts
#Launching ubuntu docker container to run yardstick
@@ -29,12 +29,12 @@ function verifyGuestImage {
fi
}
-#Updating the pod.yaml file with HOST_IP,cyclictest-node-context.yaml with loops and interval
+#Updating the pod.yaml file with HOST_IP,kvmfornfv_cyclictest_idle_idle.yaml with loops and interval
function updateYaml {
cd $WORKSPACE/tests/